%% Kyoto University, Statistical Machine Learning - Lecture 4 scripts and data
% Marco Cuturi, 2011

% Getting the data
% Obtained from http://www.amstat.org/publications/jse/datasets/body.dat
% See http://www.amstat.org/publications/jse/v11n2/datasets.heinz.html

load body.dat
% Body has now 25 columns and 507 observations. For the purpose of this 
% lecture, we are only interested in the last 3 measurements: weight (kg)
% height (cm) and gender (1-M , 0-F)

body=body(:,end-2:end);

% compute density for illustration purposes. We will assume this is the
% "real" density.

% indices corresponding to males and females
IndM= (body(:,3)==1);
IndF= (body(:,3)==0);

% ratio of counts of M/F 
MF_rat= sum(IndM+1-1)/sum(IndF+1-1);
p_M=sum(IndM+1-1)/size(body,1);

% compute the Heights of Males or Females HM,HF, and plot an estimated
% density.

[HM,XHM]= ksdensity(body(IndM,2));
[HF,XHF]= ksdensity(body(IndF,2));

% to make sure density estimates are computed in the same points.
XH=sort(unique([XHM,XHF]));
XHM=XH;
XHF=XH;
HM= ksdensity(body(IndM,2),XH);
HF= ksdensity(body(IndF,2),XH);



close all;

%% Global Densities
% 3D
jj=1;
figure(jj);
hold on;
plot3(XHM,ones(size(XHM)),HM*p_M,'r-','LineWidth',2);
plot3(XHF,zeros(size(XHF)),HF*(1-p_M),'r-','LineWidth',2);
legend({'p(X,Y)'})
set(gca,'FontSize',20);
set(gca,'YTick',[0,1]);
set(gca,'YTickLabel',{'F','M'});
view(-37.50,30);
axis tight;
title('p(Height,Gender)')
hold off;


% Height - Weight
jj=jj+1;
figure(jj);
H=body(:,2);
W=body(:,1);
N=60;
gridH=0:(1.4*max(H))/N:1.4*max(H);
gridW=0:(1.4*max(W))/N:1.4*max(W);
f= ksdensity2d([H,W],gridH,gridW);
surf(gridH,gridW,f);
view(-37.50,30);
xlabel('Height');
ylabel('Weight');
zlabel('Density');
set(gca,'FontSize',20);
axis tight;
title('p(Height,Weight)')

%% Bayes rule (eta)
jj=jj+1;
figure(jj);
hold on;
eta=(HM*p_M)./(HM*p_M+HF*(1-p_M)); 
plot(XH,eta,'b-','LineWidth',2);
hline(.5,'r--','1/2');
legend({'\eta(x)'});
set(gca,'FontSize',20);
axis tight;
hold off;


%% 
T=body(randperm(size(body,1)),2:3);
T(1:5,:)


jj=jj+1;
figure(jj);

scatter(T(1:30,1),T(1:30,2),'r');
h=hline(0,'r-');
set(gca,'YTick',[0,1]);
set(gca,'YTickLabel',{'F','M'});
set(h,'LineWidth',4);
set(gca,'FontSize',20);








